# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .energy import Energy
from .macros import Macros
from .micros import Micros
from .client_facing_food import ClientFacingFood
from .client_facing_source import ClientFacingSource
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class MealInDbBaseClientFacingSource(UniversalBaseModel):
    id: str
    user_id: str
    priority_id: int
    source_id: int
    provider_id: str
    timestamp: str
    name: str
    energy: typing.Optional[Energy] = None
    macros: typing.Optional[Macros] = None
    micros: typing.Optional[Micros] = None
    data: typing.Optional[typing.Dict[str, ClientFacingFood]] = None
    source: ClientFacingSource
    created_at: str
    updated_at: str
    source_app_id: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    ActivityColumnExpr,
    ActivityColumnExprActivity,
    ActivityV2InDb,
    AddOnOrder,
    Address,
    AggregateExpr,
    AggregateExprArg,
    AggregateExprFunc,
    AggregationResponse,
    AggregationResult,
    AllowedRadius,
    Answer,
    AoE,
    AoEAnswer,
    AppointmentAvailabilitySlots,
    AppointmentBookingRequest,
    AppointmentEventStatus,
    AppointmentLocation,
    AppointmentProvider,
    AppointmentPscLabs,
    AppointmentRescheduleRequest,
    AppointmentServiceType,
    AppointmentStatus,
    AppointmentType,
    AreaInfo,
    AttemptStatus,
    AuthType,
    Availability,
    BasalBodyTemperatureEntry,
    Billing,
    BiomarkerResult,
    BodyColumnExpr,
    BodyColumnExprBody,
    BodyV2InDb,
    CervicalMucusEntry,
    CervicalMucusEntryQuality,
    ChronotypeValueMacroExpr,
    ClientActivityResponse,
    ClientBodyResponse,
    ClientFacingAFibBurdenSample,
    ClientFacingActivity,
    ClientFacingApiKey,
    ClientFacingAppointment,
    ClientFacingAppointmentCancellationReason,
    ClientFacingAppointmentEvent,
    ClientFacingAtHomePhlebotomyOrder,
    ClientFacingAtHomePhlebotomyOrderDetails,
    ClientFacingBloodOxygenTimeseries,
    ClientFacingBloodPressureTimeseries,
    ClientFacingBody,
    ClientFacingBodyFatTimeseries,
    ClientFacingBodyTemperatureDeltaSample,
    ClientFacingBodyTemperatureDeltaSampleSensorLocation,
    ClientFacingBodyTemperatureSample,
    ClientFacingBodyTemperatureSampleSensorLocation,
    ClientFacingBodyWeightTimeseries,
    ClientFacingCaffeineTimeseries,
    ClientFacingCaloriesActiveTimeseries,
    ClientFacingCaloriesBasalTimeseries,
    ClientFacingCarbohydratesSample,
    ClientFacingCholesterolTimeseries,
    ClientFacingConnectionErrorDetails,
    ClientFacingConnectionErrorDetailsErrorType,
    ClientFacingDiagnosisInformation,
    ClientFacingDistanceTimeseries,
    ClientFacingElectrocardiogram,
    ClientFacingElectrocardiogramClassification,
    ClientFacingElectrocardiogramInconclusiveCause,
    ClientFacingElectrocardiogramResponse,
    ClientFacingElectrocardiogramSourceProvider,
    ClientFacingElectrocardiogramSourceType,
    ClientFacingElectrocardiogramVoltageTimeseries,
    ClientFacingFloorsClimbedTimeseries,
    ClientFacingFood,
    ClientFacingGlucoseTimeseries,
    ClientFacingGroupedTimeseriesResponseClientFacingAFibBurdenSample,
    ClientFacingGroupedTimeseriesResponseClientFacingBodyTemperatureDeltaSample,
    ClientFacingGroupedTimeseriesResponseClientFacingBodyTemperatureSample,
    ClientFacingGroupedTimeseriesResponseClientFacingCarbohydratesSample,
    ClientFacingGroupedTimeseriesResponseClientFacingHeartRateAlertSample,
    ClientFacingGroupedTimeseriesResponseClientFacingInsulinInjectionSample,
    ClientFacingGroupedTimeseriesResponseClientFacingNoteSample,
    ClientFacingGroupedTimeseriesResponseClientFacingWorkoutDurationSample,
    ClientFacingHeartRate,
    ClientFacingHeartRateAlertSample,
    ClientFacingHeartRateAlertSampleType,
    ClientFacingHeartRateTimeseries,
    ClientFacingHrvTimeseries,
    ClientFacingHypnogramTimeseries,
    ClientFacingIgeTimeseries,
    ClientFacingIggTimeseries,
    ClientFacingInsulinInjectionSample,
    ClientFacingInsulinInjectionSampleType,
    ClientFacingInsurance,
    ClientFacingLab,
    ClientFacingLabLocation,
    ClientFacingLabTest,
    ClientFacingLabs,
    ClientFacingLoinc,
    ClientFacingMarker,
    ClientFacingMarkerComplete,
    ClientFacingMealResponse,
    ClientFacingMenstrualCycle,
    ClientFacingMenstrualCycleSourceProvider,
    ClientFacingMenstrualCycleSourceType,
    ClientFacingMindfulnessMinutesTimeseries,
    ClientFacingNoteSample,
    ClientFacingNoteSampleTagsItem,
    ClientFacingOrder,
    ClientFacingOrderDetails,
    ClientFacingOrderDetails_AtHomePhlebotomy,
    ClientFacingOrderDetails_Testkit,
    ClientFacingOrderDetails_WalkInTest,
    ClientFacingOrderEvent,
    ClientFacingPatientDetailsCompatible,
    ClientFacingPayorSearchResponse,
    ClientFacingPayorSearchResponseDeprecated,
    ClientFacingPhysician,
    ClientFacingProfile,
    ClientFacingProvider,
    ClientFacingProviderDetailed,
    ClientFacingProviderWithStatus,
    ClientFacingResource,
    ClientFacingRespiratoryRateTimeseries,
    ClientFacingResult,
    ClientFacingSampleGroupingKeys,
    ClientFacingShipment,
    ClientFacingSleep,
    ClientFacingSleepCycle,
    ClientFacingSleepCycleSourceProvider,
    ClientFacingSleepCycleSourceType,
    ClientFacingSleepStream,
    ClientFacingSource,
    ClientFacingSport,
    ClientFacingStepsTimeseries,
    ClientFacingStream,
    ClientFacingStreamAltitude,
    ClientFacingStreamCadence,
    ClientFacingStreamDistance,
    ClientFacingStreamHeartrate,
    ClientFacingStreamLat,
    ClientFacingStreamLng,
    ClientFacingStreamPower,
    ClientFacingStreamResistance,
    ClientFacingStreamTemperature,
    ClientFacingStreamVelocitySmooth,
    ClientFacingStressLevelTimeseries,
    ClientFacingTeam,
    ClientFacingTestKitOrderDetails,
    ClientFacingTestkitOrder,
    ClientFacingTimeseriesGroupClientFacingAFibBurdenSample,
    ClientFacingTimeseriesGroupClientFacingBodyTemperatureDeltaSample,
    ClientFacingTimeseriesGroupClientFacingBodyTemperatureSample,
    ClientFacingTimeseriesGroupClientFacingCarbohydratesSample,
    ClientFacingTimeseriesGroupClientFacingHeartRateAlertSample,
    ClientFacingTimeseriesGroupClientFacingInsulinInjectionSample,
    ClientFacingTimeseriesGroupClientFacingNoteSample,
    ClientFacingTimeseriesGroupClientFacingWorkoutDurationSample,
    ClientFacingUser,
    ClientFacingUserKey,
    ClientFacingVo2MaxTimeseries,
    ClientFacingWalkInOrderDetails,
    ClientFacingWalkInTestOrder,
    ClientFacingWaterTimeseries,
    ClientFacingWorkout,
    ClientFacingWorkoutDurationSample,
    ClientFacingWorkoutDurationSampleIntensity,
    ClientSleepCycleResponse,
    ClientSleepResponse,
    ClientUserIdConflict,
    ClientWorkoutResponse,
    CompanyDetails,
    ConnectedSourceClientFacing,
    ConnectionStatus,
    ConnectionStatusState,
    Consent,
    ConsentType,
    ContraceptiveEntry,
    ContraceptiveEntryType,
    DatePartExpr,
    DatePartExprArg,
    DatePartExprDatePart,
    DateTruncExpr,
    DateTruncExprArg,
    DaySlots,
    DelegatedFlowType,
    DemoConnectionStatus,
    DemoProviders,
    DetectedDeviationEntry,
    DetectedDeviationEntryDeviation,
    DeviceV2InDb,
    EmailProviders,
    Energy,
    EventDestinationPreferences,
    EventDestinationPreferencesEnabledItem,
    EventDestinationPreferencesPreferred,
    FailureType,
    FallbackBirthDate,
    FallbackTimeZone,
    Fats,
    Gender,
    GetMarkersResponse,
    GetOrdersResponse,
    GroupKeyColumnExpr,
    GroupKeyColumnExprGroupKey,
    GroupedBloodOxygen,
    GroupedBloodOxygenResponse,
    GroupedBloodPressure,
    GroupedBloodPressureResponse,
    GroupedBodyFat,
    GroupedBodyFatResponse,
    GroupedBodyWeight,
    GroupedBodyWeightResponse,
    GroupedCaffeine,
    GroupedCaffeineResponse,
    GroupedCaloriesActive,
    GroupedCaloriesActiveResponse,
    GroupedCaloriesBasal,
    GroupedCaloriesBasalResponse,
    GroupedCholesterol,
    GroupedCholesterolResponse,
    GroupedDistance,
    GroupedDistanceResponse,
    GroupedElectrocardiogramVoltage,
    GroupedElectrocardiogramVoltageResponse,
    GroupedFloorsClimbed,
    GroupedFloorsClimbedResponse,
    GroupedGlucose,
    GroupedGlucoseResponse,
    GroupedHeartRate,
    GroupedHeartRateResponse,
    GroupedHrv,
    GroupedHrvResponse,
    GroupedHypnogram,
    GroupedHypnogramResponse,
    GroupedIge,
    GroupedIgeResponse,
    GroupedIgg,
    GroupedIggResponse,
    GroupedMindfulnessMinutes,
    GroupedMindfulnessMinutesResponse,
    GroupedRespiratoryRate,
    GroupedRespiratoryRateResponse,
    GroupedSteps,
    GroupedStepsResponse,
    GroupedStressLevel,
    GroupedStressLevelResponse,
    GroupedVo2Max,
    GroupedVo2MaxResponse,
    GroupedWater,
    GroupedWaterResponse,
    GuarantorDetails,
    HealthInsuranceCreateRequest,
    HealthInsuranceCreateRequestBackImage,
    HealthInsuranceCreateRequestFrontImage,
    HealthInsuranceCreateRequestPatientSignatureImage,
    HistoricalPullStatus,
    HistoricalPullTimeline,
    HomePregnancyTestEntry,
    HomePregnancyTestEntryTestResult,
    HomeProgesteroneTestEntry,
    HomeProgesteroneTestEntryTestResult,
    HttpValidationError,
    IndexColumnExpr,
    IndexColumnExprIndex,
    IntermenstrualBleedingEntry,
    Jpeg,
    LabLocationMetadata,
    LabResultsMetadata,
    LabResultsRaw,
    LabResultsRawResults,
    LabTestCollectionMethod,
    LabTestSampleType,
    LabTestStatus,
    Labs,
    LastAttempt,
    LibreConfig,
    LinkTokenExchangeResponse,
    LngLat,
    Macros,
    ManualProviders,
    MarkerType,
    MealInDbBaseClientFacingSource,
    MenstrualCycleResponse,
    MenstrualFlowEntry,
    MenstrualFlowEntryFlow,
    MetricsResult,
    Micros,
    Minerals,
    MissingBiomarkerResult,
    OAuthProviders,
    OrderSetRequest,
    OrderStatus,
    OrderTopLevelStatus,
    OvulationTestEntry,
    OvulationTestEntryTestResult,
    PaginatedUsersResponse,
    ParentBiomarkerData,
    PasswordProviders,
    PatientAddressCompatible,
    PatientAddressWithValidation,
    PatientDetails,
    PatientDetailsWithValidation,
    PayorCodeExternalProvider,
    Period,
    PeriodUnit,
    PersonDetailsOutput,
    PhlebotomyAreaInfo,
    PhlebotomyProviderInfo,
    PhysicianCreateRequest,
    PhysicianCreateRequestBase,
    PhysicianCreateRequestSignatureImage,
    Placeholder,
    Png,
    PostOrderResponse,
    ProfileInDb,
    ProviderLinkResponse,
    ProviderLinkResponseState,
    ProviderMfaRequest,
    ProviderMfaRequestMethod,
    Providers,
    PscAreaInfo,
    PscAreaInfoDetails,
    PscInfo,
    Query,
    QueryConfig,
    QueryConfigProviderPriorityOverridesItem,
    QueryGroupByItem,
    QuerySelectItem,
    Question,
    QuestionType,
    RawActivity,
    RawBody,
    RawDevices,
    RawProfile,
    RawSleep,
    RawWorkout,
    Region,
    RelativeTimeframe,
    ResourceAvailability,
    ResponsibleRelationship,
    ResultType,
    ScopeRequirementsGrants,
    ScopeRequirementsStr,
    Select,
    SexualActivityEntry,
    ShippingAddress,
    SingleHistoricalPullStatistics,
    SingleProviderHistoricalPullResponse,
    SingleResourceStatistics,
    SingleUserHistoricalPullResponse,
    SingleUserResourceResponse,
    SleepColumnExpr,
    SleepColumnExprSleep,
    SleepScoreValueMacroExpr,
    SleepSummaryState,
    SleepType,
    SleepV2InDb,
    Source,
    SourceAuthType,
    SourceLink,
    SourceType,
    TeamConfig,
    TimeSlot,
    TimeseriesMetricPoint,
    TimeseriesResource,
    TraceElements,
    UnrecognizedValueMacroExpr,
    UsAddress,
    UserHistoricalPullsResponse,
    UserInfo,
    UserRefreshErrorResponse,
    UserRefreshSuccessResponse,
    UserResourcesResponse,
    UserSignInTokenResponse,
    UserSuccessResponse,
    ValidationError,
    ValidationErrorLocItem,
    VitalCoreSchemasDbSchemasLabTestHealthInsurancePersonDetails,
    VitalCoreSchemasDbSchemasLabTestInsurancePersonDetails,
    VitalSleepStage,
    VitalTokenCreatedResponse,
    Vitamins,
    WorkoutColumnExpr,
    WorkoutColumnExprWorkout,
    WorkoutV2InDb,
)
from .errors import BadRequestError, UnprocessableEntityError
from . import (
    activity,
    aggregate,
    body,
    devices,
    electrocardiogram,
    insurance,
    introspect,
    lab_tests,
    link,
    meal,
    menstrual_cycle,
    profile,
    providers,
    sleep,
    sleep_cycle,
    team,
    testkit,
    user,
    vitals,
    workouts,
)
from .aggregate import QueryBatchTimeframe
from .client import AsyncVital, Vital
from .environment import VitalEnvironment
from .lab_tests import LabTestsGetOrdersRequestOrderDirection, LabTestsGetOrdersRequestOrderKey
from .version import __version__

__all__ = [
    "ActivityColumnExpr",
    "ActivityColumnExprActivity",
    "ActivityV2InDb",
    "AddOnOrder",
    "Address",
    "AggregateExpr",
    "AggregateExprArg",
    "AggregateExprFunc",
    "AggregationResponse",
    "AggregationResult",
    "AllowedRadius",
    "Answer",
    "AoE",
    "AoEAnswer",
    "AppointmentAvailabilitySlots",
    "AppointmentBookingRequest",
    "AppointmentEventStatus",
    "AppointmentLocation",
    "AppointmentProvider",
    "AppointmentPscLabs",
    "AppointmentRescheduleRequest",
    "AppointmentServiceType",
    "AppointmentStatus",
    "AppointmentType",
    "AreaInfo",
    "AsyncVital",
    "AttemptStatus",
    "AuthType",
    "Availability",
    "BadRequestError",
    "BasalBodyTemperatureEntry",
    "Billing",
    "BiomarkerResult",
    "BodyColumnExpr",
    "BodyColumnExprBody",
    "BodyV2InDb",
    "CervicalMucusEntry",
    "CervicalMucusEntryQuality",
    "ChronotypeValueMacroExpr",
    "ClientActivityResponse",
    "ClientBodyResponse",
    "ClientFacingAFibBurdenSample",
    "ClientFacingActivity",
    "ClientFacingApiKey",
    "ClientFacingAppointment",
    "ClientFacingAppointmentCancellationReason",
    "ClientFacingAppointmentEvent",
    "ClientFacingAtHomePhlebotomyOrder",
    "ClientFacingAtHomePhlebotomyOrderDetails",
    "ClientFacingBloodOxygenTimeseries",
    "ClientFacingBloodPressureTimeseries",
    "ClientFacingBody",
    "ClientFacingBodyFatTimeseries",
    "ClientFacingBodyTemperatureDeltaSample",
    "ClientFacingBodyTemperatureDeltaSampleSensorLocation",
    "ClientFacingBodyTemperatureSample",
    "ClientFacingBodyTemperatureSampleSensorLocation",
    "ClientFacingBodyWeightTimeseries",
    "ClientFacingCaffeineTimeseries",
    "ClientFacingCaloriesActiveTimeseries",
    "ClientFacingCaloriesBasalTimeseries",
    "ClientFacingCarbohydratesSample",
    "ClientFacingCholesterolTimeseries",
    "ClientFacingConnectionErrorDetails",
    "ClientFacingConnectionErrorDetailsErrorType",
    "ClientFacingDiagnosisInformation",
    "ClientFacingDistanceTimeseries",
    "ClientFacingElectrocardiogram",
    "ClientFacingElectrocardiogramClassification",
    "ClientFacingElectrocardiogramInconclusiveCause",
    "ClientFacingElectrocardiogramResponse",
    "ClientFacingElectrocardiogramSourceProvider",
    "ClientFacingElectrocardiogramSourceType",
    "ClientFacingElectrocardiogramVoltageTimeseries",
    "ClientFacingFloorsClimbedTimeseries",
    "ClientFacingFood",
    "ClientFacingGlucoseTimeseries",
    "ClientFacingGroupedTimeseriesResponseClientFacingAFibBurdenSample",
    "ClientFacingGroupedTimeseriesResponseClientFacingBodyTemperatureDeltaSample",
    "ClientFacingGroupedTimeseriesResponseClientFacingBodyTemperatureSample",
    "ClientFacingGroupedTimeseriesResponseClientFacingCarbohydratesSample",
    "ClientFacingGroupedTimeseriesResponseClientFacingHeartRateAlertSample",
    "ClientFacingGroupedTimeseriesResponseClientFacingInsulinInjectionSample",
    "ClientFacingGroupedTimeseriesResponseClientFacingNoteSample",
    "ClientFacingGroupedTimeseriesResponseClientFacingWorkoutDurationSample",
    "ClientFacingHeartRate",
    "ClientFacingHeartRateAlertSample",
    "ClientFacingHeartRateAlertSampleType",
    "ClientFacingHeartRateTimeseries",
    "ClientFacingHrvTimeseries",
    "ClientFacingHypnogramTimeseries",
    "ClientFacingIgeTimeseries",
    "ClientFacingIggTimeseries",
    "ClientFacingInsulinInjectionSample",
    "ClientFacingInsulinInjectionSampleType",
    "ClientFacingInsurance",
    "ClientFacingLab",
    "ClientFacingLabLocation",
    "ClientFacingLabTest",
    "ClientFacingLabs",
    "ClientFacingLoinc",
    "ClientFacingMarker",
    "ClientFacingMarkerComplete",
    "ClientFacingMealResponse",
    "ClientFacingMenstrualCycle",
    "ClientFacingMenstrualCycleSourceProvider",
    "ClientFacingMenstrualCycleSourceType",
    "ClientFacingMindfulnessMinutesTimeseries",
    "ClientFacingNoteSample",
    "ClientFacingNoteSampleTagsItem",
    "ClientFacingOrder",
    "ClientFacingOrderDetails",
    "ClientFacingOrderDetails_AtHomePhlebotomy",
    "ClientFacingOrderDetails_Testkit",
    "ClientFacingOrderDetails_WalkInTest",
    "ClientFacingOrderEvent",
    "ClientFacingPatientDetailsCompatible",
    "ClientFacingPayorSearchResponse",
    "ClientFacingPayorSearchResponseDeprecated",
    "ClientFacingPhysician",
    "ClientFacingProfile",
    "ClientFacingProvider",
    "ClientFacingProviderDetailed",
    "ClientFacingProviderWithStatus",
    "ClientFacingResource",
    "ClientFacingRespiratoryRateTimeseries",
    "ClientFacingResult",
    "ClientFacingSampleGroupingKeys",
    "ClientFacingShipment",
    "ClientFacingSleep",
    "ClientFacingSleepCycle",
    "ClientFacingSleepCycleSourceProvider",
    "ClientFacingSleepCycleSourceType",
    "ClientFacingSleepStream",
    "ClientFacingSource",
    "ClientFacingSport",
    "ClientFacingStepsTimeseries",
    "ClientFacingStream",
    "ClientFacingStreamAltitude",
    "ClientFacingStreamCadence",
    "ClientFacingStreamDistance",
    "ClientFacingStreamHeartrate",
    "ClientFacingStreamLat",
    "ClientFacingStreamLng",
    "ClientFacingStreamPower",
    "ClientFacingStreamResistance",
    "ClientFacingStreamTemperature",
    "ClientFacingStreamVelocitySmooth",
    "ClientFacingStressLevelTimeseries",
    "ClientFacingTeam",
    "ClientFacingTestKitOrderDetails",
    "ClientFacingTestkitOrder",
    "ClientFacingTimeseriesGroupClientFacingAFibBurdenSample",
    "ClientFacingTimeseriesGroupClientFacingBodyTemperatureDeltaSample",
    "ClientFacingTimeseriesGroupClientFacingBodyTemperatureSample",
    "ClientFacingTimeseriesGroupClientFacingCarbohydratesSample",
    "ClientFacingTimeseriesGroupClientFacingHeartRateAlertSample",
    "ClientFacingTimeseriesGroupClientFacingInsulinInjectionSample",
    "ClientFacingTimeseriesGroupClientFacingNoteSample",
    "ClientFacingTimeseriesGroupClientFacingWorkoutDurationSample",
    "ClientFacingUser",
    "ClientFacingUserKey",
    "ClientFacingVo2MaxTimeseries",
    "ClientFacingWalkInOrderDetails",
    "ClientFacingWalkInTestOrder",
    "ClientFacingWaterTimeseries",
    "ClientFacingWorkout",
    "ClientFacingWorkoutDurationSample",
    "ClientFacingWorkoutDurationSampleIntensity",
    "ClientSleepCycleResponse",
    "ClientSleepResponse",
    "ClientUserIdConflict",
    "ClientWorkoutResponse",
    "CompanyDetails",
    "ConnectedSourceClientFacing",
    "ConnectionStatus",
    "ConnectionStatusState",
    "Consent",
    "ConsentType",
    "ContraceptiveEntry",
    "ContraceptiveEntryType",
    "DatePartExpr",
    "DatePartExprArg",
    "DatePartExprDatePart",
    "DateTruncExpr",
    "DateTruncExprArg",
    "DaySlots",
    "DelegatedFlowType",
    "DemoConnectionStatus",
    "DemoProviders",
    "DetectedDeviationEntry",
    "DetectedDeviationEntryDeviation",
    "DeviceV2InDb",
    "EmailProviders",
    "Energy",
    "EventDestinationPreferences",
    "EventDestinationPreferencesEnabledItem",
    "EventDestinationPreferencesPreferred",
    "FailureType",
    "FallbackBirthDate",
    "FallbackTimeZone",
    "Fats",
    "Gender",
    "GetMarkersResponse",
    "GetOrdersResponse",
    "GroupKeyColumnExpr",
    "GroupKeyColumnExprGroupKey",
    "GroupedBloodOxygen",
    "GroupedBloodOxygenResponse",
    "GroupedBloodPressure",
    "GroupedBloodPressureResponse",
    "GroupedBodyFat",
    "GroupedBodyFatResponse",
    "GroupedBodyWeight",
    "GroupedBodyWeightResponse",
    "GroupedCaffeine",
    "GroupedCaffeineResponse",
    "GroupedCaloriesActive",
    "GroupedCaloriesActiveResponse",
    "GroupedCaloriesBasal",
    "GroupedCaloriesBasalResponse",
    "GroupedCholesterol",
    "GroupedCholesterolResponse",
    "GroupedDistance",
    "GroupedDistanceResponse",
    "GroupedElectrocardiogramVoltage",
    "GroupedElectrocardiogramVoltageResponse",
    "GroupedFloorsClimbed",
    "GroupedFloorsClimbedResponse",
    "GroupedGlucose",
    "GroupedGlucoseResponse",
    "GroupedHeartRate",
    "GroupedHeartRateResponse",
    "GroupedHrv",
    "GroupedHrvResponse",
    "GroupedHypnogram",
    "GroupedHypnogramResponse",
    "GroupedIge",
    "GroupedIgeResponse",
    "GroupedIgg",
    "GroupedIggResponse",
    "GroupedMindfulnessMinutes",
    "GroupedMindfulnessMinutesResponse",
    "GroupedRespiratoryRate",
    "GroupedRespiratoryRateResponse",
    "GroupedSteps",
    "GroupedStepsResponse",
    "GroupedStressLevel",
    "GroupedStressLevelResponse",
    "GroupedVo2Max",
    "GroupedVo2MaxResponse",
    "GroupedWater",
    "GroupedWaterResponse",
    "GuarantorDetails",
    "HealthInsuranceCreateRequest",
    "HealthInsuranceCreateRequestBackImage",
    "HealthInsuranceCreateRequestFrontImage",
    "HealthInsuranceCreateRequestPatientSignatureImage",
    "HistoricalPullStatus",
    "HistoricalPullTimeline",
    "HomePregnancyTestEntry",
    "HomePregnancyTestEntryTestResult",
    "HomeProgesteroneTestEntry",
    "HomeProgesteroneTestEntryTestResult",
    "HttpValidationError",
    "IndexColumnExpr",
    "IndexColumnExprIndex",
    "IntermenstrualBleedingEntry",
    "Jpeg",
    "LabLocationMetadata",
    "LabResultsMetadata",
    "LabResultsRaw",
    "LabResultsRawResults",
    "LabTestCollectionMethod",
    "LabTestSampleType",
    "LabTestStatus",
    "LabTestsGetOrdersRequestOrderDirection",
    "LabTestsGetOrdersRequestOrderKey",
    "Labs",
    "LastAttempt",
    "LibreConfig",
    "LinkTokenExchangeResponse",
    "LngLat",
    "Macros",
    "ManualProviders",
    "MarkerType",
    "MealInDbBaseClientFacingSource",
    "MenstrualCycleResponse",
    "MenstrualFlowEntry",
    "MenstrualFlowEntryFlow",
    "MetricsResult",
    "Micros",
    "Minerals",
    "MissingBiomarkerResult",
    "OAuthProviders",
    "OrderSetRequest",
    "OrderStatus",
    "OrderTopLevelStatus",
    "OvulationTestEntry",
    "OvulationTestEntryTestResult",
    "PaginatedUsersResponse",
    "ParentBiomarkerData",
    "PasswordProviders",
    "PatientAddressCompatible",
    "PatientAddressWithValidation",
    "PatientDetails",
    "PatientDetailsWithValidation",
    "PayorCodeExternalProvider",
    "Period",
    "PeriodUnit",
    "PersonDetailsOutput",
    "PhlebotomyAreaInfo",
    "PhlebotomyProviderInfo",
    "PhysicianCreateRequest",
    "PhysicianCreateRequestBase",
    "PhysicianCreateRequestSignatureImage",
    "Placeholder",
    "Png",
    "PostOrderResponse",
    "ProfileInDb",
    "ProviderLinkResponse",
    "ProviderLinkResponseState",
    "ProviderMfaRequest",
    "ProviderMfaRequestMethod",
    "Providers",
    "PscAreaInfo",
    "PscAreaInfoDetails",
    "PscInfo",
    "Query",
    "QueryBatchTimeframe",
    "QueryConfig",
    "QueryConfigProviderPriorityOverridesItem",
    "QueryGroupByItem",
    "QuerySelectItem",
    "Question",
    "QuestionType",
    "RawActivity",
    "RawBody",
    "RawDevices",
    "RawProfile",
    "RawSleep",
    "RawWorkout",
    "Region",
    "RelativeTimeframe",
    "ResourceAvailability",
    "ResponsibleRelationship",
    "ResultType",
    "ScopeRequirementsGrants",
    "ScopeRequirementsStr",
    "Select",
    "SexualActivityEntry",
    "ShippingAddress",
    "SingleHistoricalPullStatistics",
    "SingleProviderHistoricalPullResponse",
    "SingleResourceStatistics",
    "SingleUserHistoricalPullResponse",
    "SingleUserResourceResponse",
    "SleepColumnExpr",
    "SleepColumnExprSleep",
    "SleepScoreValueMacroExpr",
    "SleepSummaryState",
    "SleepType",
    "SleepV2InDb",
    "Source",
    "SourceAuthType",
    "SourceLink",
    "SourceType",
    "TeamConfig",
    "TimeSlot",
    "TimeseriesMetricPoint",
    "TimeseriesResource",
    "TraceElements",
    "UnprocessableEntityError",
    "UnrecognizedValueMacroExpr",
    "UsAddress",
    "UserHistoricalPullsResponse",
    "UserInfo",
    "UserRefreshErrorResponse",
    "UserRefreshSuccessResponse",
    "UserResourcesResponse",
    "UserSignInTokenResponse",
    "UserSuccessResponse",
    "ValidationError",
    "ValidationErrorLocItem",
    "Vital",
    "VitalCoreSchemasDbSchemasLabTestHealthInsurancePersonDetails",
    "VitalCoreSchemasDbSchemasLabTestInsurancePersonDetails",
    "VitalEnvironment",
    "VitalSleepStage",
    "VitalTokenCreatedResponse",
    "Vitamins",
    "WorkoutColumnExpr",
    "WorkoutColumnExprWorkout",
    "WorkoutV2InDb",
    "__version__",
    "activity",
    "aggregate",
    "body",
    "devices",
    "electrocardiogram",
    "insurance",
    "introspect",
    "lab_tests",
    "link",
    "meal",
    "menstrual_cycle",
    "profile",
    "providers",
    "sleep",
    "sleep_cycle",
    "team",
    "testkit",
    "user",
    "vitals",
    "workouts",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .jpeg import Jpeg
from .png import Png

HealthInsuranceCreateRequestPatientSignatureImage = typing.Union[Jpeg, Png]



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from .types.query_batch_timeframe import QueryBatchTimeframe
from ..types.query import Query
from ..types.query_config import QueryConfig
from ..core.request_options import RequestOptions
from ..types.aggregation_response import AggregationResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class AggregateClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def query_one(
        self,
        user_id: str,
        *,
        timeframe: QueryBatchTimeframe,
        queries: typing.Sequence[Query],
        config: typing.Optional[QueryConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AggregationResponse:
        """
        Parameters
        ----------
        user_id : str

        timeframe : QueryBatchTimeframe

        queries : typing.Sequence[Query]

        config : typing.Optional[QueryConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AggregationResponse
            Successful Response

        Examples
        --------
        from vital import (
            AggregateExpr,
            AggregateExprFunc,
            Period,
            PeriodUnit,
            Query,
            RelativeTimeframe,
            SleepColumnExpr,
            SleepColumnExprSleep,
            Vital,
        )

        client = Vital(
            api_key="YOUR_API_KEY",
        )
        client.aggregate.query_one(
            user_id="user_id",
            timeframe=RelativeTimeframe(
                anchor="anchor",
                past=Period(
                    unit=PeriodUnit.MINUTE,
                ),
            ),
            queries=[
                Query(
                    select=[
                        AggregateExpr(
                            arg=SleepColumnExpr(
                                sleep=SleepColumnExprSleep.SESSION_START,
                            ),
                            func=AggregateExprFunc.MEAN,
                        )
                    ],
                )
            ],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"aggregate/v1/user/{jsonable_encoder(user_id)}/query",
            method="POST",
            json={
                "timeframe": timeframe,
                "queries": queries,
                "config": config,
            },
            headers={
                "accept": "*/*",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AggregationResponse,
                    parse_obj_as(
                        type_=AggregationResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncAggregateClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def query_one(
        self,
        user_id: str,
        *,
        timeframe: QueryBatchTimeframe,
        queries: typing.Sequence[Query],
        config: typing.Optional[QueryConfig] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AggregationResponse:
        """
        Parameters
        ----------
        user_id : str

        timeframe : QueryBatchTimeframe

        queries : typing.Sequence[Query]

        config : typing.Optional[QueryConfig]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AggregationResponse
            Successful Response

        Examples
        --------
        import asyncio

        from vital import (
            AggregateExpr,
            AggregateExprFunc,
            AsyncVital,
            Period,
            PeriodUnit,
            Query,
            RelativeTimeframe,
            SleepColumnExpr,
            SleepColumnExprSleep,
        )

        client = AsyncVital(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.aggregate.query_one(
                user_id="user_id",
                timeframe=RelativeTimeframe(
                    anchor="anchor",
                    past=Period(
                        unit=PeriodUnit.MINUTE,
                    ),
                ),
                queries=[
                    Query(
                        select=[
                            AggregateExpr(
                                arg=SleepColumnExpr(
                                    sleep=SleepColumnExprSleep.SESSION_START,
                                ),
                                func=AggregateExprFunc.MEAN,
                            )
                        ],
                    )
                ],
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"aggregate/v1/user/{jsonable_encoder(user_id)}/query",
            method="POST",
            json={
                "timeframe": timeframe,
                "queries": queries,
                "config": config,
            },
            headers={
                "accept": "*/*",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    AggregationResponse,
                    parse_obj_as(
                        type_=AggregationResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
from .providers import Providers
from .labs import Labs

ClientFacingElectrocardiogramSourceProvider = typing.Union[Providers, Labs]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ConnectionStatusState(str, enum.Enum):
    SUCCESS = "success"
    ERROR = "error"
    PENDING_PROVIDER_MFA = "pending_provider_mfa"

    def visit(
        self,
        success: typing.Callable[[], T_Result],
        error: typing.Callable[[], T_Result],
        pending_provider_mfa: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ConnectionStatusState.SUCCESS:
            return success()
        if self is ConnectionStatusState.ERROR:
            return error()
        if self is ConnectionStatusState.PENDING_PROVIDER_MFA:
            return pending_provider_mfa()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentEventStatus(str, enum.Enum):
    PENDING = "pending"
    SCHEDULED = "scheduled"
    COMPLETED = "completed"
    CANCELLED = "cancelled"
    IN_PROGRESS = "in_progress"

    def visit(
        self,
        pending: typing.Callable[[], T_Result],
        scheduled: typing.Callable[[], T_Result],
        completed: typing.Callable[[], T_Result],
        cancelled: typing.Callable[[], T_Result],
        in_progress: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is AppointmentEventStatus.PENDING:
            return pending()
        if self is AppointmentEventStatus.SCHEDULED:
            return scheduled()
        if self is AppointmentEventStatus.COMPLETED:
            return completed()
        if self is AppointmentEventStatus.CANCELLED:
            return cancelled()
        if self is AppointmentEventStatus.IN_PROGRESS:
            return in_progress()



# This file was auto-generated by Fern from our API Definition.

import typing
from .index_column_expr import IndexColumnExpr
from .placeholder import Placeholder

DatePartExprArg = typing.Union[IndexColumnExpr, Placeholder]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class TimeseriesResource(str, enum.Enum):
    CALORIES_ACTIVE = "calories_active"
    CALORIES_BASAL = "calories_basal"
    DISTANCE = "distance"
    BLOOD_OXYGEN = "blood_oxygen"
    BLOOD_PRESSURE = "blood_pressure"
    BODY_FAT = "body_fat"
    BODY_WEIGHT = "body_weight"
    BODY_TEMPERATURE = "body_temperature"
    BODY_TEMPERATURE_DELTA = "body_temperature_delta"
    CHOLESTEROL = "cholesterol"
    CHOLESTEROL_LDL = "cholesterol/ldl"
    CHOLESTEROL_HDL = "cholesterol/hdl"
    CHOLESTEROL_TOTAL = "cholesterol/total"
    CHOLESTEROL_TRIGLYCERIDES = "cholesterol/triglycerides"
    ELECTROCARDIOGRAM_VOLTAGE = "electrocardiogram_voltage"
    FLOORS_CLIMBED = "floors_climbed"
    GLUCOSE = "glucose"
    HEARTRATE = "heartrate"
    HRV = "hrv"
    HYPNOGRAM = "hypnogram"
    IGE = "ige"
    IGG = "igg"
    RESPIRATORY_RATE = "respiratory_rate"
    STEPS = "steps"
    STRESS_LEVEL = "stress_level"
    VO_2_MAX = "vo2_max"
    WATER = "water"
    CAFFEINE = "caffeine"
    MINDFULNESS_MINUTES = "mindfulness_minutes"
    AFIB_BURDEN = "afib_burden"
    HEART_RATE_ALERT = "heart_rate_alert"
    WORKOUT_DURATION = "workout_duration"
    INSULIN_INJECTION = "insulin_injection"
    CARBOHYDRATES = "carbohydrates"
    NOTE = "note"

    def visit(
        self,
        calories_active: typing.Callable[[], T_Result],
        calories_basal: typing.Callable[[], T_Result],
        distance: typing.Callable[[], T_Result],
        blood_oxygen: typing.Callable[[], T_Result],
        blood_pressure: typing.Callable[[], T_Result],
        body_fat: typing.Callable[[], T_Result],
        body_weight: typing.Callable[[], T_Result],
        body_temperature: typing.Callable[[], T_Result],
        body_temperature_delta: typing.Callable[[], T_Result],
        cholesterol: typing.Callable[[], T_Result],
        cholesterol_ldl: typing.Callable[[], T_Result],
        cholesterol_hdl: typing.Callable[[], T_Result],
        cholesterol_total: typing.Callable[[], T_Result],
        cholesterol_triglycerides: typing.Callable[[], T_Result],
        electrocardiogram_voltage: typing.Callable[[], T_Result],
        floors_climbed: typing.Callable[[], T_Result],
        glucose: typing.Callable[[], T_Result],
        heartrate: typing.Callable[[], T_Result],
        hrv: typing.Callable[[], T_Result],
        hypnogram: typing.Callable[[], T_Result],
        ige: typing.Callable[[], T_Result],
        igg: typing.Callable[[], T_Result],
        respiratory_rate: typing.Callable[[], T_Result],
        steps: typing.Callable[[], T_Result],
        stress_level: typing.Callable[[], T_Result],
        vo_2_max: typing.Callable[[], T_Result],
        water: typing.Callable[[], T_Result],
        caffeine: typing.Callable[[], T_Result],
        mindfulness_minutes: typing.Callable[[], T_Result],
        afib_burden: typing.Callable[[], T_Result],
        heart_rate_alert: typing.Callable[[], T_Result],
        workout_duration: typing.Callable[[], T_Result],
        insulin_injection: typing.Callable[[], T_Result],
        carbohydrates: typing.Callable[[], T_Result],
        note: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is TimeseriesResource.CALORIES_ACTIVE:
            return calories_active()
        if self is TimeseriesResource.CALORIES_BASAL:
            return calories_basal()
        if self is TimeseriesResource.DISTANCE:
            return distance()
        if self is TimeseriesResource.BLOOD_OXYGEN:
            return blood_oxygen()
        if self is TimeseriesResource.BLOOD_PRESSURE:
            return blood_pressure()
        if self is TimeseriesResource.BODY_FAT:
            return body_fat()
        if self is TimeseriesResource.BODY_WEIGHT:
            return body_weight()
        if self is TimeseriesResource.BODY_TEMPERATURE:
            return body_temperature()
        if self is TimeseriesResource.BODY_TEMPERATURE_DELTA:
            return body_temperature_delta()
        if self is TimeseriesResource.CHOLESTEROL:
            return cholesterol()
        if self is TimeseriesResource.CHOLESTEROL_LDL:
            return cholesterol_ldl()
        if self is TimeseriesResource.CHOLESTEROL_HDL:
            return cholesterol_hdl()
        if self is TimeseriesResource.CHOLESTEROL_TOTAL:
            return cholesterol_total()
        if self is TimeseriesResource.CHOLESTEROL_TRIGLYCERIDES:
            return cholesterol_triglycerides()
        if self is TimeseriesResource.ELECTROCARDIOGRAM_VOLTAGE:
            return electrocardiogram_voltage()
        if self is TimeseriesResource.FLOORS_CLIMBED:
            return floors_climbed()
        if self is TimeseriesResource.GLUCOSE:
            return glucose()
        if self is TimeseriesResource.HEARTRATE:
            return heartrate()
        if self is TimeseriesResource.HRV:
            return hrv()
        if self is TimeseriesResource.HYPNOGRAM:
            return hypnogram()
        if self is TimeseriesResource.IGE:
            return ige()
        if self is TimeseriesResource.IGG:
            return igg()
        if self is TimeseriesResource.RESPIRATORY_RATE:
            return respiratory_rate()
        if self is TimeseriesResource.STEPS:
            return steps()
        if self is TimeseriesResource.STRESS_LEVEL:
            return stress_level()
        if self is TimeseriesResource.VO_2_MAX:
            return vo_2_max()
        if self is TimeseriesResource.WATER:
            return water()
        if self is TimeseriesResource.CAFFEINE:
            return caffeine()
        if self is TimeseriesResource.MINDFULNESS_MINUTES:
            return mindfulness_minutes()
        if self is TimeseriesResource.AFIB_BURDEN:
            return afib_burden()
        if self is TimeseriesResource.HEART_RATE_ALERT:
            return heart_rate_alert()
        if self is TimeseriesResource.WORKOUT_DURATION:
            return workout_duration()
        if self is TimeseriesResource.INSULIN_INJECTION:
            return insulin_injection()
        if self is TimeseriesResource.CARBOHYDRATES:
            return carbohydrates()
        if self is TimeseriesResource.NOTE:
            return note()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PayorCodeExternalProvider(str, enum.Enum):
    CHANGE_HEALTHCARE = "change_healthcare"
    AVAILITY = "availity"

    def visit(
        self, change_healthcare: typing.Callable[[], T_Result], availity: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is PayorCodeExternalProvider.CHANGE_HEALTHCARE:
            return change_healthcare()
        if self is PayorCodeExternalProvider.AVAILITY:
            return availity()



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
import typing
from ..core.request_options import RequestOptions
from ..types.menstrual_cycle_response import MenstrualCycleResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper


class MenstrualCycleClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(
        self,
        user_id: str,
        *,
        start_date: str,
        provider: typing.Optional[str] = None,
        end_date: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> MenstrualCycleResponse:
        """
        Parameters
        ----------
        user_id : str

        start_date : str

        provider : typing.Optional[str]
            Provider oura/strava etc

        end_date : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        MenstrualCycleResponse
            Successful Response

        Examples
        --------
        from vital import Vital

        client = Vital(
            api_key="YOUR_API_KEY",
        )
        client.menstrual_cycle.get(
            user_id="user_id",
            start_date="start_date",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/summary/menstrual_cycle/{jsonable_encoder(user_id)}",
            method="GET",
            params={
                "provider": provider,
                "start_date": start_date,
                "end_date": end_date,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    MenstrualCycleResponse,
                    parse_obj_as(
                        type_=MenstrualCycleResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncMenstrualCycleClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(
        self,
        user_id: str,
        *,
        start_date: str,
        provider: typing.Optional[str] = None,
        end_date: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> MenstrualCycleResponse:
        """
        Parameters
        ----------
        user_id : str

        start_date : str

        provider : typing.Optional[str]
            Provider oura/strava etc

        end_date : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        MenstrualCycleResponse
            Successful Response

        Examples
        --------
        import asyncio

        from vital import AsyncVital

        client = AsyncVital(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.menstrual_cycle.get(
                user_id="user_id",
                start_date="start_date",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/summary/menstrual_cycle/{jsonable_encoder(user_id)}",
            method="GET",
            params={
                "provider": provider,
                "start_date": start_date,
                "end_date": end_date,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    MenstrualCycleResponse,
                    parse_obj_as(
                        type_=MenstrualCycleResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
from ...types.relative_timeframe import RelativeTimeframe
from ...types.placeholder import Placeholder

QueryBatchTimeframe = typing.Union[RelativeTimeframe, Placeholder]



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
import typing
from ..types.providers import Providers
from ..core.request_options import RequestOptions
from ..types.user_resources_response import UserResourcesResponse
from ..core.pydantic_utilities import parse_obj_as
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..types.user_historical_pulls_response import UserHistoricalPullsResponse
from ..core.client_wrapper import AsyncClientWrapper


class IntrospectClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_user_resources(
        self,
        *,
        user_id: typing.Optional[str] = None,
        provider: typing.Optional[Providers] = None,
        user_limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        next_cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UserResourcesResponse:
        """
        Parameters
        ----------
        user_id : typing.Optional[str]

        provider : typing.Optional[Providers]

        user_limit : typing.Optional[int]

        cursor : typing.Optional[str]

        next_cursor : typing.Optional[str]
            The cursor for fetching the next page, or `null` to fetch the first page.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UserResourcesResponse
            Successful Response

        Examples
        --------
        from vital import Vital

        client = Vital(
            api_key="YOUR_API_KEY",
        )
        client.introspect.get_user_resources()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/introspect/resources",
            method="GET",
            params={
                "user_id": user_id,
                "provider": provider,
                "user_limit": user_limit,
                "cursor": cursor,
                "next_cursor": next_cursor,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    UserResourcesResponse,
                    parse_obj_as(
                        type_=UserResourcesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_user_historical_pulls(
        self,
        *,
        user_id: typing.Optional[str] = None,
        provider: typing.Optional[Providers] = None,
        user_limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        next_cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UserHistoricalPullsResponse:
        """
        Parameters
        ----------
        user_id : typing.Optional[str]

        provider : typing.Optional[Providers]

        user_limit : typing.Optional[int]

        cursor : typing.Optional[str]

        next_cursor : typing.Optional[str]
            The cursor for fetching the next page, or `null` to fetch the first page.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UserHistoricalPullsResponse
            Successful Response

        Examples
        --------
        from vital import Vital

        client = Vital(
            api_key="YOUR_API_KEY",
        )
        client.introspect.get_user_historical_pulls()
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/introspect/historical_pull",
            method="GET",
            params={
                "user_id": user_id,
                "provider": provider,
                "user_limit": user_limit,
                "cursor": cursor,
                "next_cursor": next_cursor,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    UserHistoricalPullsResponse,
                    parse_obj_as(
                        type_=UserHistoricalPullsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncIntrospectClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_user_resources(
        self,
        *,
        user_id: typing.Optional[str] = None,
        provider: typing.Optional[Providers] = None,
        user_limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        next_cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UserResourcesResponse:
        """
        Parameters
        ----------
        user_id : typing.Optional[str]

        provider : typing.Optional[Providers]

        user_limit : typing.Optional[int]

        cursor : typing.Optional[str]

        next_cursor : typing.Optional[str]
            The cursor for fetching the next page, or `null` to fetch the first page.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UserResourcesResponse
            Successful Response

        Examples
        --------
        import asyncio

        from vital import AsyncVital

        client = AsyncVital(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.introspect.get_user_resources()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/introspect/resources",
            method="GET",
            params={
                "user_id": user_id,
                "provider": provider,
                "user_limit": user_limit,
                "cursor": cursor,
                "next_cursor": next_cursor,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    UserResourcesResponse,
                    parse_obj_as(
                        type_=UserResourcesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_user_historical_pulls(
        self,
        *,
        user_id: typing.Optional[str] = None,
        provider: typing.Optional[Providers] = None,
        user_limit: typing.Optional[int] = None,
        cursor: typing.Optional[str] = None,
        next_cursor: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UserHistoricalPullsResponse:
        """
        Parameters
        ----------
        user_id : typing.Optional[str]

        provider : typing.Optional[Providers]

        user_limit : typing.Optional[int]

        cursor : typing.Optional[str]

        next_cursor : typing.Optional[str]
            The cursor for fetching the next page, or `null` to fetch the first page.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UserHistoricalPullsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from vital import AsyncVital

        client = AsyncVital(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.introspect.get_user_historical_pulls()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/introspect/historical_pull",
            method="GET",
            params={
                "user_id": user_id,
                "provider": provider,
                "user_limit": user_limit,
                "cursor": cursor,
                "next_cursor": next_cursor,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    UserHistoricalPullsResponse,
                    parse_obj_as(
                        type_=UserHistoricalPullsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .energy import Energy
from .macros import Macros
from .micros import Micros
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ClientFacingFood(UniversalBaseModel):
    energy: typing.Optional[Energy] = None
    macros: typing.Optional[Macros] = None
    micros: typing.Optional[Micros] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
